pub enum ResampleAlgorithm {
Linear {
lpf_order: u32,
lpf_nyquist_factor: f64,
},
Speex {
quality: u32,
},
}Expand description
The choice of resampling algorithm depends on your situation and requirements. The linear resampler is the most efficient and has the least amount of latency, but at the expense of poorer quality. The Speex resampler is higher quality, but slower with more latency. It also performs several heap allocations internally for memory management.
Variants
Implementations
Sourceimpl ResampleAlgorithm
impl ResampleAlgorithm
pub fn algorithm_type(&self) -> ResampleAlgorithmType